==> HSAUR2_1.0-1.tar.gz: HSAUR2/tests/Ch_simple_inference.R <==
###################################################
### chunk number 1: setup
###################################################
rm(list = ls())
if (!file.exists("tables")) dir.create("tables")
set.seed(290875)
options(prompt = "R> ", continue = "+  ",
    width = 63, # digits = 4,
    show.signif.stars = FALSE,
    SweaveHooks = list(leftpar = function()
        par(mai = par("mai") * c(1, 1.05, 1, 1)),
        bigleftpar = function()
        par(mai = par("mai") * c(1, 1.7, 1, 1))))
HSAURpkg <- require("HSAUR2")
if (!HSAURpkg) stop("cannot load package ", sQuote("HSAUR2"))
rm(HSAURpkg)
 ### </FIXME> hm, R-2.4.0 --vanilla seems to need this
a <- Sys.setlocale("LC_ALL", "C")
 ### </FIXME>
book <- TRUE
refs <- cbind(c("AItR", "DAGD", "SI", "CI", "ANOVA", "MLR", "GLM",
                "DE", "RP", "GAM", "SA", "ALDI", "ALDII", "SIMC", "MA", "PCA",
                "MDS", "CA"), 1:18)
ch <- function(x) {
    ch <- refs[which(refs[,1] == x),]
    if (book) {
        return(paste("Chapter~\\\\ref{", ch[1], "}", sep = ""))
    } else {
        return(paste("Chapter~", ch[2], sep = ""))
    }
}
if (file.exists("deparse.R"))
    source("deparse.R")
setHook(packageEvent("lattice", "attach"), function(...) {
    lattice.options(default.theme =
        function()
            standard.theme("pdf", color = FALSE))
    })


###################################################
### chunk number 2: singlebook
###################################################
book <- FALSE


###################################################
### chunk number 3: SI-setup
###################################################
library("vcd")
if (!interactive()) {
print.htest <- function (x, digits = 4, quote = TRUE, prefix = "", ...)
{
    cat("\n")
    cat(strwrap(x$method, prefix = "\t"), sep = "\n")
    cat("\n")
    cat("data: ", x$data.name, "\n")
    out <- character()
    if (!is.null(x$statistic))
        out <- c(out, paste(names(x$statistic), "=", format(round(x$statistic,
            4))))
    if (!is.null(x$parameter))
        out <- c(out, paste(names(x$parameter), "=", format(round(x$parameter,
            3))))
    if (!is.null(x$p.value)) {
        fp <- format.pval(x$p.value, digits = digits)
        out <- c(out, paste("p-value", if (substr(fp, 1, 1) ==
            "<") fp else paste("=", fp)))
    }
    cat(strwrap(paste(out, collapse = ", ")), sep = "\n")
    if (!is.null(x$conf.int)) {
        cat(format(100 * attr(x$conf.int, "conf.level")), "percent confidence interval:\n",
            format(c(x$conf.int[1], x$conf.int[2])), "\n")
    }
    if (!is.null(x$estimate)) {
        cat("sample estimates:\n")
        print(x$estimate, ...)
    }
    cat("\n")
    invisible(x)
}
}


###################################################
### chunk number 4: SI-roomwidth-data
###################################################
data("roomwidth", package = "HSAUR2")


###################################################
### chunk number 5: SI-roomwidth-convert
###################################################
convert <- ifelse(roomwidth$unit == "feet", 1, 3.28)


###################################################
### chunk number 6: SI-roomwidth-summary
###################################################
tapply(roomwidth$width * convert, roomwidth$unit, summary)
tapply(roomwidth$width * convert, roomwidth$unit, sd)


###################################################
### chunk number 7: SI-roomwidth-boxplot
###################################################
layout(matrix(c(1,2,1,3), nrow = 2, ncol = 2, byrow = FALSE))
boxplot(I(width * convert) ~ unit, data = roomwidth,
        ylab = "Estimated width (feet)",
        varwidth = TRUE, names = c("Estimates in feet",
        "Estimates in metres (converted to feet)"))
feet <- roomwidth$unit == "feet"
qqnorm(roomwidth$width[feet],
       ylab = "Estimated width (feet)")
qqline(roomwidth$width[feet])
qqnorm(roomwidth$width[!feet],
       ylab = "Estimated width (metres)")
qqline(roomwidth$width[!feet])


###################################################
### chunk number 8: SI-roomwidth-formula
###################################################
I(width * convert) ~ unit


###################################################
### chunk number 9: SI-roomwidth-tt-T-hide
###################################################
tt <- t.test(I(width * convert) ~ unit, data = roomwidth,
             var.equal = TRUE)


###################################################
### chunk number 10: SI-roomwidth-tt-T
###################################################
t.test(I(width * convert) ~ unit, data = roomwidth,
       var.equal = TRUE)


###################################################
### chunk number 11: SI-roomwidth-tt-F
###################################################
t.test(I(width * convert) ~ unit, data = roomwidth,
       var.equal = FALSE)


###################################################
### chunk number 12: SI-roomwidth-wt
###################################################
wilcox.test(I(width * convert) ~ unit, data = roomwidth,
            conf.int = TRUE)


###################################################
### chunk number 13: SI-roomwidth-wt-hide
###################################################
pwt <- round(wilcox.test(I(width * convert) ~ unit, data =
             roomwidth)$p.value, 3)


###################################################
### chunk number 14: SI-waves-data
###################################################
data("waves", package = "HSAUR2")


###################################################
### chunk number 15: SI-wavese-boxplot
###################################################
mooringdiff <- waves$method1 - waves$method2
layout(matrix(1:2, ncol = 2))
boxplot(mooringdiff, ylab = "Differences (Newton metres)",
        main = "Boxplot")
abline(h = 0, lty = 2)
qqnorm(mooringdiff, ylab = "Differences (Newton metres)")
qqline(mooringdiff)


###################################################
### chunk number 16: SI-waves-tt
###################################################
t.test(mooringdiff)


###################################################
### chunk number 17: SI-waves-wt
###################################################
pwt <- round(wilcox.test(mooringdiff)$p.value, 3)


###################################################
### chunk number 18: SI-waves-wt
###################################################
wilcox.test(mooringdiff)


###################################################
### chunk number 19: SI-water-data
###################################################
data("water", package = "HSAUR2")


###################################################
### chunk number 20: SI-water-plot
###################################################
nf <- layout(matrix(c(2, 0, 1, 3), 2, 2, byrow = TRUE),
             c(2, 1), c(1, 2), TRUE)
psymb <- as.numeric(water$location)
plot(mortality ~ hardness, data = water, pch = psymb)
abline(lm(mortality ~ hardness, data = water))
legend("topright", legend = levels(water$location),
       pch = c(1,2), bty = "n")
hist(water$hardness)
boxplot(water$mortality)


###################################################
### chunk number 21: SI-water-cor
###################################################
cor.test(~ mortality + hardness, data = water)


###################################################
### chunk number 22: SI-water-cor
###################################################
cr <- round(cor.test(~ mortality + hardness, data = water)$estimate, 3)


###################################################
### chunk number 23: SI-pistonrings-chisq-hide
###################################################
chisqt <- chisq.test(pistonrings)


###################################################
### chunk number 24: SI-pistonrings-chisq
###################################################
data("pistonrings", package = "HSAUR2")
chisq.test(pistonrings)


###################################################
### chunk number 25: SI-pistonrings-resid
###################################################
chisq.test(pistonrings)$residuals


###################################################
### chunk number 26: SI-assoc-plot
###################################################
library("vcd")
assoc(pistonrings)


###################################################
### chunk number 27: SI-rearrests-data
###################################################
data("rearrests", package = "HSAUR2")
rearrests


###################################################
### chunk number 28: SI-rearrests-mcnemar
###################################################
mcs <- round(mcnemar.test(rearrests, correct = FALSE)$statistic, 2)


###################################################
### chunk number 29: SI-arrests-mcnemar
###################################################
mcnemar.test(rearrests, correct = FALSE)


###################################################
### chunk number 30: SI-arrests-binom
###################################################
binom.test(rearrests[2], n = sum(rearrests[c(2,3)]))

==> HSAUR2_1.0-2.tar.gz: HSAUR2/tests/Ch_simple_inference.R <==
###################################################
### chunk number 1: setup
###################################################
#line 182 "Ch_simple_inference.Rnw"
rm(list = ls())
if (!file.exists("tables")) dir.create("tables")
if (!file.exists("figures")) dir.create("figures")
set.seed(290875)
options(prompt = "R> ", continue = "+  ",
    width = 63, # digits = 4,
    show.signif.stars = FALSE,
    SweaveHooks = list(leftpar = function()
        par(mai = par("mai") * c(1, 1.05, 1, 1)),
        bigleftpar = function()
        par(mai = par("mai") * c(1, 1.7, 1, 1))))
HSAURpkg <- require("HSAUR2")
if (!HSAURpkg) stop("cannot load package ", sQuote("HSAUR2"))
rm(HSAURpkg)
 ### </FIXME> hm, R-2.4.0 --vanilla seems to need this
a <- Sys.setlocale("LC_ALL", "C")
 ### </FIXME>
book <- TRUE
refs <- cbind(c("AItR", "DAGD", "SI", "CI", "ANOVA", "MLR", "GLM",
                "DE", "RP", "GAM", "SA", "ALDI", "ALDII", "SIMC", "MA", "PCA",
                "MDS", "CA"), 1:18)
ch <- function(x) {
    ch <- refs[which(refs[,1] == x),]
    if (book) {
        return(paste("Chapter~\\\\ref{", ch[1], "}", sep = ""))
    } else {
        return(paste("Chapter~", ch[2], sep = ""))
    }
}
if (file.exists("deparse.R"))
    source("deparse.R")
setHook(packageEvent("lattice", "attach"), function(...) {
    lattice.options(default.theme =
        function()
            standard.theme("pdf", color = FALSE))
    })


###################################################
### chunk number 2: singlebook
###################################################
#line 221 "Ch_simple_inference.Rnw"
book <- FALSE


###################################################
### chunk number 3: SI-setup
###################################################
#line 228 "Ch_simple_inference.Rnw"
library("vcd")
if (!interactive()) {
print.htest <- function (x, digits = 4, quote = TRUE, prefix = "", ...)
{
    cat("\n")
    cat(strwrap(x$method, prefix = "\t"), sep = "\n")
    cat("\n")
    cat("data: ", x$data.name, "\n")
    out <- character()
    if (!is.null(x$statistic))
        out <- c(out, paste(names(x$statistic), "=", format(round(x$statistic,
            4))))
    if (!is.null(x$parameter))
        out <- c(out, paste(names(x$parameter), "=", format(round(x$parameter,
            3))))
    if (!is.null(x$p.value)) {
        fp <- format.pval(x$p.value, digits = digits)
        out <- c(out, paste("p-value", if (substr(fp, 1, 1) ==
            "<") fp else paste("=", fp)))
    }
    cat(strwrap(paste(out, collapse = ", ")), sep = "\n")
    if (!is.null(x$conf.int)) {
        cat(format(100 * attr(x$conf.int, "conf.level")), "percent confidence interval:\n",
            format(c(x$conf.int[1], x$conf.int[2])), "\n")
    }
    if (!is.null(x$estimate)) {
        cat("sample estimates:\n")
        print(x$estimate, ...)
    }
    cat("\n")
    invisible(x)
}
}


###################################################
### chunk number 4: SI-roomwidth-data
###################################################
#line 269 "Ch_simple_inference.Rnw"
data("roomwidth", package = "HSAUR2")


###################################################
### chunk number 5: SI-roomwidth-convert
###################################################
#line 281 "Ch_simple_inference.Rnw"
convert <- ifelse(roomwidth$unit == "feet", 1, 3.28)


###################################################
### chunk number 6: SI-roomwidth-summary
###################################################
#line 287 "Ch_simple_inference.Rnw"
tapply(roomwidth$width * convert, roomwidth$unit, summary)
tapply(roomwidth$width * convert, roomwidth$unit, sd)


###################################################
### chunk number 7: SI-roomwidth-boxplot
###################################################
#line 304 "Ch_simple_inference.Rnw"
layout(matrix(c(1,2,1,3), nrow = 2, ncol = 2, byrow = FALSE))
boxplot(I(width * convert) ~ unit, data = roomwidth,
        ylab = "Estimated width (feet)",
        varwidth = TRUE, names = c("Estimates in feet",
        "Estimates in metres (converted to feet)"))
feet <- roomwidth$unit == "feet"
qqnorm(roomwidth$width[feet],
       ylab = "Estimated width (feet)")
qqline(roomwidth$width[feet])
qqnorm(roomwidth$width[!feet],
       ylab = "Estimated width (metres)")
qqline(roomwidth$width[!feet])


###################################################
### chunk number 8: SI-roomwidth-formula
###################################################
#line 334 "Ch_simple_inference.Rnw"
I(width * convert) ~ unit


###################################################
### chunk number 9: SI-roomwidth-tt-T-hide
###################################################
#line 342 "Ch_simple_inference.Rnw"
tt <- t.test(I(width * convert) ~ unit, data = roomwidth,
             var.equal = TRUE)


###################################################
### chunk number 10: SI-roomwidth-tt-T
###################################################
#line 349 "Ch_simple_inference.Rnw"
t.test(I(width * convert) ~ unit, data = roomwidth,
       var.equal = TRUE)


###################################################
### chunk number 11: SI-roomwidth-tt-F
###################################################
#line 357 "Ch_simple_inference.Rnw"
t.test(I(width * convert) ~ unit, data = roomwidth,
       var.equal = FALSE)


###################################################
### chunk number 12: SI-roomwidth-wt
###################################################
#line 365 "Ch_simple_inference.Rnw"
wilcox.test(I(width * convert) ~ unit, data = roomwidth,
            conf.int = TRUE)


###################################################
### chunk number 13: SI-roomwidth-wt-hide
###################################################
#line 370 "Ch_simple_inference.Rnw"
pwt <- round(wilcox.test(I(width * convert) ~ unit, data =
             roomwidth)$p.value, 3)


###################################################
### chunk number 14: SI-waves-data
###################################################
#line 376 "Ch_simple_inference.Rnw"
data("waves", package = "HSAUR2")


###################################################
### chunk number 15: SI-wavese-boxplot
###################################################
#line 387 "Ch_simple_inference.Rnw"
mooringdiff <- waves$method1 - waves$method2
layout(matrix(1:2, ncol = 2))
boxplot(mooringdiff, ylab = "Differences (Newton metres)",
        main = "Boxplot")
abline(h = 0, lty = 2)
qqnorm(mooringdiff, ylab = "Differences (Newton metres)")
qqline(mooringdiff)


###################################################
### chunk number 16: SI-waves-tt
###################################################
#line 403 "Ch_simple_inference.Rnw"
t.test(mooringdiff)


###################################################
### chunk number 17: SI-waves-wt
###################################################
#line 407 "Ch_simple_inference.Rnw"
pwt <- round(wilcox.test(mooringdiff)$p.value, 3)


###################################################
### chunk number 18: SI-waves-wt
###################################################
#line 413 "Ch_simple_inference.Rnw"
wilcox.test(mooringdiff)


###################################################
### chunk number 19: SI-water-data
###################################################
#line 420 "Ch_simple_inference.Rnw"
data("water", package = "HSAUR2")


###################################################
### chunk number 20: SI-water-plot
###################################################
#line 442 "Ch_simple_inference.Rnw"
nf <- layout(matrix(c(2, 0, 1, 3), 2, 2, byrow = TRUE),
             c(2, 1), c(1, 2), TRUE)
psymb <- as.numeric(water$location)
plot(mortality ~ hardness, data = water, pch = psymb)
abline(lm(mortality ~ hardness, data = water))
legend("topright", legend = levels(water$location),
       pch = c(1,2), bty = "n")
hist(water$hardness)
boxplot(water$mortality)


###################################################
### chunk number 21: SI-water-cor
###################################################
#line 463 "Ch_simple_inference.Rnw"
cor.test(~ mortality + hardness, data = water)


###################################################
### chunk number 22: SI-water-cor
###################################################
#line 467 "Ch_simple_inference.Rnw"
cr <- round(cor.test(~ mortality + hardness, data = water)$estimate, 3)


###################################################
### chunk number 23: SI-pistonrings-chisq-hide
###################################################
#line 471 "Ch_simple_inference.Rnw"
chisqt <- chisq.test(pistonrings)


###################################################
### chunk number 24: SI-pistonrings-chisq
###################################################
#line 477 "Ch_simple_inference.Rnw"
data("pistonrings", package = "HSAUR2")
chisq.test(pistonrings)


###################################################
### chunk number 25: SI-pistonrings-resid
###################################################
#line 495 "Ch_simple_inference.Rnw"
chisq.test(pistonrings)$residuals


###################################################
### chunk number 26: SI-assoc-plot
###################################################
#line 508 "Ch_simple_inference.Rnw"
library("vcd")
assoc(pistonrings)


###################################################
### chunk number 27: SI-rearrests-data
###################################################
#line 519 "Ch_simple_inference.Rnw"
data("rearrests", package = "HSAUR2")
rearrests


###################################################
### chunk number 28: SI-rearrests-mcnemar
###################################################
#line 523 "Ch_simple_inference.Rnw"
mcs <- round(mcnemar.test(rearrests, correct = FALSE)$statistic, 2)


###################################################
### chunk number 29: SI-arrests-mcnemar
###################################################
#line 544 "Ch_simple_inference.Rnw"
mcnemar.test(rearrests, correct = FALSE)


###################################################
### chunk number 30: SI-arrests-binom
###################################################
#line 552 "Ch_simple_inference.Rnw"
binom.test(rearrests[2], n = sum(rearrests[c(2,3)]))
